aggregate_stats: Aggregate Statistics Across ID

View source: R/core_stats.R

aggregate_statsR Documentation

Aggregate Statistics Across ID

Description

aggregate_stats is a (not exported) function to aggregate stats_dm objects across IDs. Since the column names may vary by the statistic type, the behavior of aggregate depends on the subclass of stats_dm.

Usage

aggregate_stats(stat_df)

Arguments

stat_df

A data.frame of class stats_dm (see new_stats_dm())

Details

aggregate_stats calls the internal_aggregate() with the relevant arguments

Value

Returns the statistics aggregated across the relevant cols.

See Also

new_stats_dm, calc_stats, internal_aggregate()


dRiftDM documentation built on Aug. 23, 2026, 5:11 p.m.