flex_special_dependency: Set special dependencies (internal docu)

View source: R/core_flex_prms.R

flex_special_dependencyR Documentation

Set special dependencies (internal docu)

Description

Sets special dependencies so that parameters depend on other parameters. (i.e., 'prmX ~ conda == -(prmY ~ condb)')

Usage

flex_special_dependency(flex_prms_obj, formula_instr)

Arguments

flex_prms_obj

a flex_prms object

formula_instr

a string referring to "special dependency" (see modify_flex_prms)

Value

a modified flex_prms_object with a modified (linear) internal list and modified parameter and custom parameter matrices


dRiftDM documentation built on Aug. 23, 2026, 5:11 p.m.