Learn R Programming

dRiftDM (version 0.3.1)

print.summary.fits_agg_dm: Summary and Printing for fits_agg_dm Objects

Description

Methods for summarizing and printing objects of the class fits_agg_dm, which contain model fits based on aggregated data across participants.

Usage

# S3 method for summary.fits_agg_dm
print(x, ..., just_header = FALSE, round_digits = drift_dm_default_rounding())

# S3 method for fits_agg_dm summary(object, ..., select_unique = FALSE)

Value

summary.fits_agg_dm() returns a list of class summary.fits_agg_dm

(see Details for its structure).

print.summary.fits_agg_dm() returns the input object invisibly.

Arguments

x

an object of class summary.fits_agg_dm.

...

additional arguments (currently unused).

just_header

logical, if TRUE only print the header information without details. Default is FALSE.

round_digits

an integer, specifying the number of decimal places for rounding in the printed summary. Default is 3.

object

an object of class fits_agg_dm, typically generated by a call to estimate_dm.

select_unique

logical, passed to coef.drift_dm().

Details

The summary.fits_agg_dm function creates a structured summary of a fits_agg_dm object, containing:

  • summary_drift_dm_obj: A list with information about the underlying drift diffusion model (as returned by summary.drift_dm()).

  • prms: Parameter estimates obtained from the model fit. This is equivalent to a call to coef.drift_dm() on the stored model object.

  • obs_data: A list providing the number of individual participants and the average number of trials per condition across participants.

The print.summary.fits_agg_dm function formats and prints the above summary in a human-readable form.

See Also

summary.drift_dm, coef.drift_dm

Examples

Run this code
# Load example fit object
fits_agg <- get_example_fits("fits_agg")
sum_obj <- summary(fits_agg)
print(sum_obj, round_digits = 2)

Run the code above in your browser using DataLab