Methods for summarizing and printing objects of the class fits_ids_dm,
which contain multiple fits across individuals.
# S3 method for summary.fits_ids_dm
print(x, ..., just_header = FALSE, round_digits = drift_dm_default_rounding())# S3 method for fits_ids_dm
summary(object, ..., select_unique = FALSE)
summary.fits_ids_dm() returns a list of class summary.fits_ids_dm (see
the Details section summarizing each entry of this list).
print.summary.fits_ids_dm() returns invisibly the summary.fits_ids_dm
object.
an object of class summary.fits_ids_dm.
additional arguments (currently unused).
logical, if TRUE only print the header information
without details. Default is FALSE.
an integer, specifying the number of decimal places for rounding in the printed summary. Default is 3.
an object of class fits_ids_dm, generated by a call
to load_fits_ids.
logical, passed to coef.drift_dm().
The summary.fits_ids_dm function creates a summary object. The contents of
this summary object depends on whether the user supplies a fits_ids_dm
object that was created with estimate_dm() or the deprecated
function load_fits_ids().
In the first case, the object contains:
summary_drift_dm_obj: A list with information about the underlying
drift diffusion model (as returned by summary.drift_dm()).
prms: All parameter values across all conditions (essentially a call to coef() with the argument select_unique = FALSE).
stats: A named list of matrices for each condition, including mean and standard error for each parameter.
obs_data: A list providing the number of individual participants and the average number of trials per condition across participants.
optimizer: A string of the optimizer that was used
conv_info: A list providing a summary of the convergance and messages for all IDs
In the second case, the object contains:
lower and upper: Lower and upper bounds of the search space.
model_type: Description of the model type, based on class information.
prms: All parameter values across all conditions (essentially a call to coef() with the argument select_unique = FALSE).
stats: A named list of matrices for each condition, including mean and standard error for each parameter.
N: The number of individuals.
The print.summary.fits_ids_dm function displays the summary object in a
formatted manner.
# get an auxiliary object of type fits_ids_dm for demonstration purpose
all_fits <- get_example_fits("fits_ids_dm")
sum_obj <- summary(all_fits)
print(sum_obj, round_digits = 2)
Run the code above in your browser using DataLab