set_default_colors: Set Default Colors

View source: R/plotting.R

set_default_colorsR Documentation

Set Default Colors

Description

This function assigns default colors if none are provided or adjusts the color vector to match the number n

Usage

set_default_colors(colors, n)

Arguments

colors

character vector, specifying colors for conditions. If NULL, default colors are used.

n

numeric, specifying the number of colors to get.

Value

A character vector of colors of length n.


dRiftDM documentation built on Aug. 23, 2026, 5:11 p.m.